==> freifunk-openwrt-kit-1.6.37-0xff.tar.gz: www/cgi-bin-pre.sh <==
#!/bin/sh
echo Content-type: text/html
echo

cat<<EOF
<HTML>
<HEAD>
<TITLE>$(n=$(nvram get wan_hostname);echo ${n:-Funkfeuer.At}) - $TITLE</TITLE>
<META CONTENT="text/html; charset=iso-8859-1" HTTP-EQUIV="Content-Type">
<META CONTENT="no-cache" HTTP-EQUIV="cache-control">
<LINK HREF="0xff.css" REL="StyleSheet">
<LINK HREF="sven-ola*t*gmx*de" REV="made" TITLE="Sven-Ola">
<STYLE TYPE="text/css">
$(if ! grep -q '^LoadPlugin "olsrd_nameservice.so' /etc/olsrd.conf 2>&-;then echo '.plugin-services {display:none}';echo '.plugin-map {display:none}';elif test -z "`nvram get ff_adm_latlon`";then echo '.plugin-map {display:none}';fi)
</STYLE>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript"><!--
function help(e) {
if (!e) e = event;
// (virt)KeyVal is Konqueror, charCode is Moz/Firefox, else MSIE, Netscape, Opera
if (26 == e.virtKeyVal || !e.keyVal && !e.charCode && 112 == (e.which || e.keyCode)) {
var o = null;
if (e.preventDefault) {
if (e.cancelable) e.preventDefault();
o = e.target;
}
else {
e.cancelBubble = true;
o = e.srcElement;
}
while(o && '' == o.title) o = o.parentNode;
if (o) alert(o.title);
}
}
if (document.all) {
document.onkeydown = help;
document.onhelp = function(){return false;}
}
else {
document.onkeypress = help;
}
//--></SCRIPT>
</HEAD>
<BODY>
<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0" CLASS="body">
<TR>
<TD CLASS="color" HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="color" HEIGHT="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="color" HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
</TR>
<TR>
<TD CLASS="color" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="orange" COLSPAN="4">
<TABLE BORDER="0" CELLPADDING="6" CELLSPACING="0" WIDTH="100%">
<TR>
<TD ALIGN="left" VALIGN="TOP"><SMALL>v1.6.37</SMALL></TD>
<TD ALIGN="right" ROWSPAN="2" VALIGN="bottom"><A HREF="http://www.funkfeuer.at/"><IMG ALT="Funkfeuer.at" BORDER="0" HEIGHT="64" SRC="images/0xff.gif" WIDTH="243" TITLE="Funkfeuer.at"></A></TD>
</TR>
<TR>
<TD ALIGN="left" VALIGN="bottom"><A CLASS="orange" HREF="cgi-bin-index.html">Home</A>
<A CLASS="orange" HREF="cgi-bin-admin.html">Verwalten</A></TD>
</TR>
</TABLE></TD>
<TD WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
</TR>
<TR>
<TD CLASS="color" HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="color" HEIGHT="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="color" HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
</TR>
<TR>
<TD CLASS="color" HEIGHT="100%" VALIGN="top" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="color" HEIGHT="100%" VALIGN="top">
<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0" WIDTH="150">
<TR>
<TD><BIG CLASS="plugin">Inhalt</BIG></TD>
</TR>
EOF

for inc in /www/[0-9][0-9]-*;do test -n "${inc##*.sh}" && cat $inc ||. $inc;done

cat<<EOF
</TABLE></TD>
<TD CLASS="color" HEIGHT="100%" VALIGN="top" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="100%" VALIGN="top" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="100%" VALIGN="top" WIDTH="100%">
EOF

==> freifunk-openwrt-kit-1.7.4-0xff.tar.gz: www/cgi-bin-pre.sh <==
#!/bin/sh
echo Content-type: text/html
echo

cat<<EOF
<HTML>
<HEAD>
<TITLE>$(n=$(nvram get wan_hostname);echo ${n:-Funkfeuer.At}) - $TITLE</TITLE>
<META CONTENT="text/html; charset=iso-8859-1" HTTP-EQUIV="Content-Type">
<META CONTENT="no-cache" HTTP-EQUIV="cache-control">
<LINK HREF="0xff.css" REL="StyleSheet">
<LINK HREF="sven-ola*t*gmx*de" REV="made" TITLE="Sven-Ola">
<STYLE TYPE="text/css">
$(if ! grep -q '^LoadPlugin "olsrd_nameservice.so' /etc/olsrd.conf 2>&-;then echo '.plugin-services {display:none}';echo '.plugin-map {display:none}';elif test -z "`nvram get ff_adm_latlon`";then echo '.plugin-map {display:none}';fi)
</STYLE>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript"><!--
function help(e) {
if (!e) e = event;
// (virt)KeyVal is Konqueror, charCode is Moz/Firefox, else MSIE, Netscape, Opera
if (26 == e.virtKeyVal || !e.keyVal && !e.charCode && 112 == (e.which || e.keyCode)) {
var o = null;
if (e.preventDefault) {
if (e.cancelable) e.preventDefault();
o = e.target;
}
else {
e.cancelBubble = true;
o = e.srcElement;
}
while(o && '' == o.title) o = o.parentNode;
if (o) alert(o.title);
}
}
if (document.all) {
document.onkeydown = help;
document.onhelp = function(){return false;}
}
else {
document.onkeypress = help;
}
//--></SCRIPT>
</HEAD>
<BODY>
<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0" CLASS="body">
<TR>
<TD CLASS="color" HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="color" HEIGHT="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="color" HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
</TR>
<TR>
<TD CLASS="color" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="orange" COLSPAN="4">
<TABLE BORDER="0" CELLPADDING="6" CELLSPACING="0" WIDTH="100%">
<TR>
<TD ALIGN="left" VALIGN="TOP"><SMALL>v1.7.4<!--%FFVER%--></SMALL></TD>
<TD ALIGN="right" ROWSPAN="2" VALIGN="bottom"><A HREF="http://www.funkfeuer.at/"><IMG ALT="Funkfeuer.at" BORDER="0" HEIGHT="64" SRC="images/0xff.gif" WIDTH="243" TITLE="Funkfeuer.at"></A></TD>
</TR>
<TR>
<TD ALIGN="left" VALIGN="bottom"><A CLASS="orange" HREF="cgi-bin-index.html">Home</A>
<A CLASS="orange" HREF="cgi-bin-admin.html">Verwalten</A></TD>
</TR>
</TABLE></TD>
<TD WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
</TR>
<TR>
<TD CLASS="color" HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="color" HEIGHT="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="color" HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
</TR>
<TR>
<TD CLASS="color" HEIGHT="100%" VALIGN="top" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="color" HEIGHT="100%" VALIGN="top">
<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0" WIDTH="150">
<TR>
<TD><BIG CLASS="plugin">Inhalt</BIG></TD>
</TR>
EOF

for inc in /www/[0-9][0-9]-*;do case ${inc##*.sh} in ""). $inc;;*)cat $inc;;esac;done

cat<<EOF
</TABLE></TD>
<TD CLASS="color" HEIGHT="100%" VALIGN="top" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="100%" VALIGN="top" WIDTH="8"><IMG HEIGHT="8" SRC="images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="100%" VALIGN="top" WIDTH="100%">
EOF
